# pcfv: Pytorch Commonly used Function for Vision tasks

During my work on vision tasks, there are functions be needed again and agin. To make it easier when switching between projects, the most commonly used functions are summarized here. It could save some effort starting a new pytorch project for CV researches.

This packsge provides classic models like [UNet](https://lmb.informatik.uni-freiburg.de/people/ronneber/u-net/), [MSDNet](https://www.pnas.org/content/115/2/254) and some common functions like [train_loop](https://github.com/jiayangshi/pcfv/blob/23f517e3c6dfc2281381b0b69ac5d8e2eb029767/pcfv/train.py#L6).